aboutsummaryrefslogtreecommitdiff
path: root/src/checker_state.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/checker_state.rs')
-rw-r--r--src/checker_state.rs8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/checker_state.rs b/src/checker_state.rs
index 19a7c51..86f229e 100644
--- a/src/checker_state.rs
+++ b/src/checker_state.rs
@@ -13,8 +13,12 @@ pub enum CheckerError {
Rebinding(String),
#[display("The following functionality is unimplemented: {_0}")]
Unimplemented(String),
- #[display("Element claimed to belong to {claimed} but actually belongs to {real}")]
- WrongSetForElement { claimed: Set, real: Set },
+ #[display("Element {value} claimed to belong to {claimed} but actually belongs to {real}")]
+ WrongSetForElement {
+ value: ElementValue,
+ claimed: Set,
+ real: Set,
+ },
#[display("Element {element} does belong to set {claimed}: {reason}")]
ElementDoesNotBelong {
element: Element,